package com.ruoyi.buyerapi.service;

import java.util.List;
import com.ruoyi.buyerapi.domain.BuyerSubjectContent;

/**
 * 科密对应关系Service接口
 * 
 * @author ruoyi
 * @date 2022-09-19
 */
public interface IBuyerSubjectContentService 
{
    /**
     * 查询科密对应关系
     * 
     * @param id 科密对应关系主键
     * @return 科密对应关系
     */
    public BuyerSubjectContent selectBuyerSubjectContentById(String id);

    /**
     * 查询科密对应关系列表
     * 
     * @param buyerSubjectContent 科密对应关系
     * @return 科密对应关系集合
     */
    public List<BuyerSubjectContent> selectBuyerSubjectContentList(BuyerSubjectContent buyerSubjectContent);

    /**
     * 新增科密对应关系
     * 
     * @param buyerSubjectContent 科密对应关系
     * @return 结果
     */
    public int insertBuyerSubjectContent(BuyerSubjectContent buyerSubjectContent);

    /**
     * 修改科密对应关系
     * 
     * @param buyerSubjectContent 科密对应关系
     * @return 结果
     */
    public int updateBuyerSubjectContent(BuyerSubjectContent buyerSubjectContent);

    /**
     * 批量删除科密对应关系
     * 
     * @param ids 需要删除的科密对应关系主键集合
     * @return 结果
     */
    public int deleteBuyerSubjectContentByIds(String[] ids);

    /**
     * 删除科密对应关系信息
     * 
     * @param id 科密对应关系主键
     * @return 结果
     */
    public int deleteBuyerSubjectContentById(String id);
}
